ams.core.service.VarSelect
==========================

.. currentmodule:: ams.core.service

.. autoclass:: VarSelect

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~VarSelect.assign_memory
       
       
          ~VarSelect.evaluate
       
       
          ~VarSelect.get_names
       
       
          ~VarSelect.parse
       
       
          ~VarSelect.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~VarSelect.class_name
      ~VarSelect.n
      ~VarSelect.shape
      ~VarSelect.size
      ~VarSelect.v
      ~VarSelect.v0
      ~VarSelect.v1
   
   